@@ -1,66 +1,11 @@
-package Data::Hive::Store::Param;
-
 use strict;
 use warnings;
+package Data::Hive::Store::Param;
+BEGIN {
+  $Data::Hive::Store::Param::VERSION = '0.054';
+}
+# ABSTRACT: CGI::param-like store for Data::Hive
 
-=head1 NAME
-
-Data::Hive::Store::Param
-
-=head1 DESCRIPTION
-
-CGI-like param() store for Data::Hive.
-
-=head1 METHODS
-
-=head2 new
-
-  # use default method name 'param'
-  my $store = Data::Hive::Store::Param->new($obj);
-
-  # use different method name 'info'
-  my $store = Data::Hive::Store::Param->new($obj, { method => 'info' });
-
-  # escape certain characters in keys
-  my $store = Data::Hive::Store::Param->new($obj, { escape => './!' });
-
-Return a new param() store.
-
-Several interesting arguments can be passed in a hashref
-after the first (mandatory) object argument.
-
-=over 
-
-=item * method
-
-Use a different method name on the object (default is 'param').
-
-=item * escape
-
-List of characters to escape (prepend '\' to) in keys.
-
-Defaults to the C<< separator >>.
-
-=item * separator
-
-String to join path segments together with; defaults to
-either the first character of the C<< escape >> option (if
-given) or '.'.
-
-=item * exists
-
-Coderef that describes how to see if a given parameter name
-(C<< separator >>-joined path) exists.  The default is to
-treat the object like a hashref and look inside it.
-
-=item * delete
-
-Coderef that describes how to delete a given parameter name.  The default is to
-treat the object like a hashref and call C<delete> on it.
-
-=back
-
-=cut
 
 sub _escape {
   my ($self, $str) = @_;
@@ -74,12 +19,6 @@ sub _path {
   return join $self->{separator}, map { $self->_escape($_) } @$path;
 }
 
-=head2 new
-
-  my $store = Data::Hive::Store::Param->new($obj, \%arg);
-
-=cut
-
 sub new {
   my ($class, $obj, $arg) = @_;
   $arg              ||= {};
@@ -99,45 +38,24 @@ sub _param {
   return $self->{obj}->$meth($path, @_);
 }
 
-=head2 get
-
-Join the path together with the C<< separator >> and get it
-from the object.
-
-=cut
 
 sub get {
   my ($self, $path) = @_;
   return $self->_param($path);
 }
 
-=head2 set
-
-See L</get>.
-
-=cut
 
 sub set {
   my ($self, $path, $val) = @_;
   return $self->_param($path => $val);
 }
 
-=head2 name
-
-Join path together with C<< separator >> and return it.
-
-=cut
  
 sub name {
   my ($self, $path) = @_;
   return $self->_path($path);
 }
 
-=head2 exists
-
-Return true if the C<< name >> of this hive is a parameter.
-
-=cut
 
 sub exists {
   my ($self, $path) = @_;
@@ -146,11 +64,6 @@ sub exists {
   return ref($code) ? $code->($key) : $self->{obj}->$code($key);
 }
 
-=head2 delete
-
-Delete the entry for the C<< name >> of this hive and return its old value.
-
-=cut
 
 sub delete {
   my ($self, $path) = @_;
@@ -160,3 +73,106 @@ sub delete {
 }
 
 1;
+
+__END__
+=pod
+
+=head1 NAME
+
+Data::Hive::Store::Param - CGI::param-like store for Data::Hive
+
+=head1 VERSION
+
+version 0.054
+
+=head1 METHODS
+
+=head2 new
+
+  # use default method name 'param'
+  my $store = Data::Hive::Store::Param->new($obj);
+
+  # use different method name 'info'
+  my $store = Data::Hive::Store::Param->new($obj, { method => 'info' });
+
+  # escape certain characters in keys
+  my $store = Data::Hive::Store::Param->new($obj, { escape => './!' });
+
+Return a new Param store.
+
+Several interesting arguments can be passed in a hashref after the first
+(mandatory) object argument.
+
+=over 4
+
+=item method
+
+Use a different method name on the object (default is 'param').
+
+=item escape
+
+List of characters to escape (prepend '\' to) in keys.
+
+Defaults to the C<< separator >>.
+
+=item separator
+
+String to join path segments together with; defaults to either the first
+character of the C<< escape >> option (if given) or '.'.
+
+=item exists
+
+Coderef that describes how to see if a given parameter name (C<< separator
+>>-joined path) exists.  The default is to treat the object like a hashref and
+look inside it.
+
+=item delete
+
+Coderef that describes how to delete a given parameter name.  The default is to
+treat the object like a hashref and call C<delete> on it.
+
+=back
+
+=head2 get
+
+Join the path together with the C<< separator >> and get it from the object.
+
+=head2 set
+
+See L</get>.
+
+=head2 name
+
+Join path together with C<< separator >> and return it.
+
+=head2 exists
+
+Return true if the C<< name >> of this hive is a parameter.
+
+=head2 delete
+
+Delete the entry for the C<< name >> of this hive and return its old value.
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Hans Dieter Pearcey <hdp@cpan.org>
+
+=item *
+
+Ricardo Signes <rjbs@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2006 by Hans Dieter Pearcey.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
